You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@tomcat.apache.org by Gr...@pfizer.com on 2004/03/01 18:04:17 UTC

RE: jk2 buglets


> -----Original Message-----
> From: Guenter Knauf [mailto:eflash@gmx.net]
> Sent: 27 February 2004 16:13
> To: tomcat-dev@jakarta.apache.org
> Subject: RE: jk2 buglets
> 
> 
> hmm, you could check to use the old mmap code which Henri 
> just has checked in again; get latest jk_shm.c from cvs and 
> modifiy it to ignore APR_HAS_MMAP and use HAVE_MMAP instead; 
> if that works then we know for sure that APR mmap supportg is 
> somehow broken on Solaris, and you have to ask in the apr 
> group for a fix...
> 
> Guenter.

Good call.  Ignoring APR results in an so that starts and responds
apparently without error.

Assuming that the next mod_jk2 release wants to go with the present APR
(0.94) or even the CVS (pre 1.0?) then we need to kludge mod_jk on solaris 8
(at least) to not use APR for this bit.

I was going to add an && defined(foo) to the APR defined lines, however I do
not know the right foo to add __sun seems too broad.  The next more complex
fix is to alter the Makefile with a -d.

What do people think?

Thanks Guenter.

Greg





> 
> 
> 
> ---------------------------------------------------------------------
> To unsubscribe, e-mail: tomcat-dev-unsubscribe@jakarta.apache.org
> For additional commands, e-mail: tomcat-dev-help@jakarta.apache.org
> 

---------------------------------------------------------------------
To unsubscribe, e-mail: tomcat-dev-unsubscribe@jakarta.apache.org
For additional commands, e-mail: tomcat-dev-help@jakarta.apache.org


Re: jk2 buglets

Posted by Glenn Nielsen <gl...@mail.more.net>.
In my apache 2.0.48 install the version of apr is 0.95.

Glenn

On Mon, Mar 01, 2004 at 05:04:17PM -0000, Greg.Cope@pfizer.com wrote:
> 
> 
> > -----Original Message-----
> > From: Guenter Knauf [mailto:eflash@gmx.net]
> > Sent: 27 February 2004 16:13
> > To: tomcat-dev@jakarta.apache.org
> > Subject: RE: jk2 buglets
> > 
> > 
> > hmm, you could check to use the old mmap code which Henri 
> > just has checked in again; get latest jk_shm.c from cvs and 
> > modifiy it to ignore APR_HAS_MMAP and use HAVE_MMAP instead; 
> > if that works then we know for sure that APR mmap supportg is 
> > somehow broken on Solaris, and you have to ask in the apr 
> > group for a fix...
> > 
> > Guenter.
> 
> Good call.  Ignoring APR results in an so that starts and responds
> apparently without error.
> 
> Assuming that the next mod_jk2 release wants to go with the present APR
> (0.94) or even the CVS (pre 1.0?) then we need to kludge mod_jk on solaris 8
> (at least) to not use APR for this bit.
> 
> I was going to add an && defined(foo) to the APR defined lines, however I do
> not know the right foo to add __sun seems too broad.  The next more complex
> fix is to alter the Makefile with a -d.
> 
> What do people think?
> 
> Thanks Guenter.
> 
> Greg
> 
> 
> 
> 
> 
> > 
> > 
> > 
> > ---------------------------------------------------------------------
> > To unsubscribe, e-mail: tomcat-dev-unsubscribe@jakarta.apache.org
> > For additional commands, e-mail: tomcat-dev-help@jakarta.apache.org
> > 
> 
> ---------------------------------------------------------------------
> To unsubscribe, e-mail: tomcat-dev-unsubscribe@jakarta.apache.org
> For additional commands, e-mail: tomcat-dev-help@jakarta.apache.org
----------------------------------------------------------------------
Glenn Nielsen             glenn@more.net | /* Spelin donut madder    |
MOREnet System Programming               |  * if iz ina coment.      |
Missouri Research and Education Network  |  */                       |
----------------------------------------------------------------------

---------------------------------------------------------------------
To unsubscribe, e-mail: tomcat-dev-unsubscribe@jakarta.apache.org
For additional commands, e-mail: tomcat-dev-help@jakarta.apache.org


[PATCH] ./jk/native2/server/apache2/mod_jk2.c - correct log entries

Posted by Guenter Knauf <ef...@gmx.net>.
Hi,
found some misleading entries in the logs...

http://www.gknw.com/test/mod_jk2.c.diff
========================================================================
--- isapi.dsp.orig      Thu Feb 12 10:34:34 2004
+++ isapi.dsp           Tue Mar 16 14:56:58 2004
@@ -54,7 +54,7 @@
 # ADD BSC32 /nologo
 LINK32=link.exe
 # ADD BASE LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib /nologo /dll /machine:I386
-# ADD LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib wsock32.lib notes.lib /nologo /dll /machine:I386 /out:"Release/tomcat_redirector.dll" /libpath:"C:\notesapi\lib\mswin32"
+# ADD LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib wsock32.lib /nologo /dll /machine:I386 /out:"Release/tomcat_redirector.dll"
 
 !ELSEIF  "$(CFG)" == "isapi - Win32 Debug"
 
@@ -81,7 +81,7 @@
 # ADD BSC32 /nologo
 LINK32=link.exe
 # ADD BASE LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib /nologo /dll /debug /machine:I386 /pdbtype:sept
-# ADD LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib wsock32.lib notes.lib /nologo /dll /debug /machine:I386 /out:"Debug/tomcat_redirector.dll" /pdbtype:sept /libpath:"C:\notesapi\lib\mswin32"
+# ADD LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib wsock32.lib /nologo /dll /debug /machine:I386 /out:"Debug/tomcat_redirector.dll" /pdbtype:sept
 
 !ENDIF 


Guenter.


---------------------------------------------------------------------
To unsubscribe, e-mail: tomcat-dev-unsubscribe@jakarta.apache.org
For additional commands, e-mail: tomcat-dev-help@jakarta.apache.org


Re: [PATCH] ./jk/native2/common/jk_worker_status.c - dont print style with text/plain

Posted by Henri Gomez <hg...@apache.org>.


Commited

---------------------------------------------------------------------
To unsubscribe, e-mail: tomcat-dev-unsubscribe@jakarta.apache.org
For additional commands, e-mail: tomcat-dev-help@jakarta.apache.org


[PATCH] ./jk/native2/common/jk_worker_status.c - dont print style with text/plain

Posted by Guenter Knauf <ef...@gmx.net>.
Hi,
this simple patch supresses the output of the style when we are in text/plain mode.

========================================================================
--- jk_worker_status.c.orig	Mon Mar 15 16:04:08 2004
+++ jk_worker_status.c	Tue Mar 16 04:02:24 2004
@@ -953,7 +953,10 @@
                         
     s->head(env, s );
 
-    s->jkprintf(env, s, "<style>%s</style>\n", DEFAULT_CSS );
+    if( !(s->query_string != NULL &&
+        strncmp( s->query_string, "qry=", 4) == 0 ) ) {
+        s->jkprintf(env, s, "<style>%s</style>\n", DEFAULT_CSS );
+    }
 
     /** Process the query string.
      */

Guenter.


---------------------------------------------------------------------
To unsubscribe, e-mail: tomcat-dev-unsubscribe@jakarta.apache.org
For additional commands, e-mail: tomcat-dev-help@jakarta.apache.org


RE: jk2 buglets

Posted by Mladen Turk <mt...@apache.org>.
 

> -----Original Message-----
> From: Guenter Knauf
> 
> > If it's a APR bug are there any patches that we can propose?
> no.
> The problem is the NetWare OS self. We had formerly no SHM 
> 
> > The netware, and windows doesn't need shm at all. 
> that's not true from APR sight: if I look into apr.h for 
> NetWare I have not one define for SHM, but looking at apr.h 

Look, the shm in jk2 is _eventually_ needed only on multi-child mpm's which
netware isn't, so why all the fuzz?

> I really would like to have APR_HAS_MMAP on NetWare since a 
> couple of other interesting modules rely on it; and be sure 
> that I bother them at Novell enough with this.
> 

Cool :-).

MT.



---------------------------------------------------------------------
To unsubscribe, e-mail: tomcat-dev-unsubscribe@jakarta.apache.org
For additional commands, e-mail: tomcat-dev-help@jakarta.apache.org


RE: jk2 buglets

Posted by Guenter Knauf <ef...@gmx.net>.
Hi,

>> > Also, we adopted the APR as mandatory, so, all platform
>> specific code
>> > except JNI has to go out (sooner or later).
>> sure, I know - but you cant expect that every APR also
>> supports SHM/MMAP; so cant we take only those things which
>> are common to all platforms?

> Does it work in APR from CVS?
no.

> If not then it's a bug in APR.
no.

> If it's a APR bug are there any patches that we can propose?
no.
The problem is the NetWare OS self. We had formerly no SHM support at all on NetWare, and since about a year we got mmap() silently, but with EXPERIMENTAL status. Since we ship recent NetWare versions with Apache (1.3 with NW6 and 2.0 with NW6.5) I cant introduce another Apache with experimental stuff in it - instead I have to rely on what's officially released - NW admins are just used to fetch a binary and drop it in, they have no plan of recompiling Apache, nor they are able to do even if they would like since NetWare doesnt ship with a compiler at all.

> The netware, and windows doesn't need shm at all. 
that's not true from APR sight: if I look into apr.h for NetWare I have not one define for SHM, but looking at apr.h from Win32 platform I can see:
#define APR_HAS_SHARED_MEMORY     1
#define APR_HAS_MMAP              1

> The final solution would be adding jk2_shm_xxxx (for specific platform),
> inside commons/arch.
> I'm not in favor of using #defines to solve that.
+1.

> If the number of needed platform specific workarounds is too high, then we
> made a mistake switching to APR, but I doubt.
no, the switch is OK, but it was probably only too early to make it mandatory.
I would have left the old code in; it was known to work, and didnt bite someone; and at least for Apache 1.3 I'm not happy with the change to APR. If I had choosen to make APR mandatory I also would have dropped Apache 1.3 support at all from mod_jk2.

> Let's make and test, and then we'll see how to solve the particular
> problem for a XXX.XXX platform.
what we all need is time - those working at APR, as well as the OS core folks - I'm sure all these things will be fixed sooner or later, but unless Apache 2.x gets widely accepted there will not be so much pressure to fix those things I feel....
I'm next month at Novell and will certainly discuss this issue with the core OS team - after that I hope I have an idea if we get mmap() and friends exported by the OS officially, and how long it may take.
I really would like to have APR_HAS_MMAP on NetWare since a couple of other interesting modules rely on it;
and be sure that I bother them at Novell enough with this.

Guenter.



---------------------------------------------------------------------
To unsubscribe, e-mail: tomcat-dev-unsubscribe@jakarta.apache.org
For additional commands, e-mail: tomcat-dev-help@jakarta.apache.org


RE: jk2 buglets

Posted by Mladen Turk <mt...@apache.org>.
 

> -----Original Message-----
> From: Guenter Knauf
> >> but what will we all loose if then the scoreboard isnt active??
> >>
> 
> > In case of single child mpm, nothing.
> > On others, jkstatus at least.
> so the scoreboard is only for collecting stats?
> 

And for load balancing stats.

> > Also, we adopted the APR as mandatory, so, all platform 
> specific code 
> > except JNI has to go out (sooner or later).
> sure, I know - but you cant expect that every APR also 
> supports SHM/MMAP; so cant we take only those things which 
> are common to all platforms? 

Does it work in APR from CVS?
If not then it's a bug in APR.
If it's a APR bug are there any patches that we can propose?


> I mean, I see there's a workaround for HPUX, so why not a 
> workaround for NetWare and Solaris and whatever else platform 
> with broken shm too? Apache2 works without shm/mmap in 
> general, so it would be fine if mod_jk2 doesnt expect more 
> than Apache2 from APR....
> 

The netware, and windows doesn't need shm at all. There is one child
process, so all the data is available to each worker thread. 
All the workarounds has to go out, except the platform specific channels.

The final solution would be adding jk2_shm_xxxx (for specific platform),
inside commons/arch.
I'm not in favor of using #defines to solve that.

If the number of needed platform specific workarounds is too high, then we
made a mistake switching to APR, but I doubt.
Let's make and test, and then we'll see how to solve the particular problem
for a XXX.XXX platform.

MT.


---------------------------------------------------------------------
To unsubscribe, e-mail: tomcat-dev-unsubscribe@jakarta.apache.org
For additional commands, e-mail: tomcat-dev-help@jakarta.apache.org


RE: jk2 buglets

Posted by Guenter Knauf <ef...@gmx.net>.
Hi Mladen,

>> but what will we all loose if then the scoreboard isnt active??
>>

> In case of single child mpm, nothing.
> On others, jkstatus at least.
so the scoreboard is only for collecting stats?

> Also, we adopted the APR as mandatory, so, all platform specific code
> except JNI has to go out (sooner or later).
sure, I know - but you cant expect that every APR also supports SHM/MMAP; 
so cant we take only those things which are common to all platforms? 
I mean, I see there's a workaround for HPUX, so why not a workaround for NetWare and Solaris and whatever else platform with broken shm too? Apache2 works without shm/mmap in general, so it would be fine if mod_jk2 doesnt expect more than Apache2 from APR....

Guenter.



---------------------------------------------------------------------
To unsubscribe, e-mail: tomcat-dev-unsubscribe@jakarta.apache.org
For additional commands, e-mail: tomcat-dev-help@jakarta.apache.org


RE: jk2 buglets

Posted by Mladen Turk <mt...@apache.org>.
 

> -----Original Message-----
> From: Guenter Knauf
> > Look at my today post (JK2 shm).
> > It's going to use the shm.
> > If the platform is missing APR_HAS_SHARED_MEMORY the shm 
> will be disabled.
> > Also you can alway set the shm to disabled if the APR 
> platform MMAP is 
> > buggy.
> 
> but what will we all loose if then the scoreboard isnt active??
> 

In case of single child mpm, nothing.
On others, jkstatus at least.

Also, we adopted the APR as mandatory, so, all platform specific code except
JNI has to go out (sooner or later).

MT.



---------------------------------------------------------------------
To unsubscribe, e-mail: tomcat-dev-unsubscribe@jakarta.apache.org
For additional commands, e-mail: tomcat-dev-help@jakarta.apache.org


RE: jk2 buglets

Posted by Guenter Knauf <ef...@gmx.net>.
Hi,

> Look at my today post (JK2 shm).
> It's going to use the shm.
> If the platform is missing APR_HAS_SHARED_MEMORY the shm will be disabled.
> Also you can alway set the shm to disabled if the APR platform MMAP is
> buggy.

but what will we all loose if then the scoreboard isnt active??

Guenter.


---------------------------------------------------------------------
To unsubscribe, e-mail: tomcat-dev-unsubscribe@jakarta.apache.org
For additional commands, e-mail: tomcat-dev-help@jakarta.apache.org


RE: jk2 buglets

Posted by Mladen Turk <mt...@apache.org>.
 

> -----Original Message-----
> From: Greg.Cope@pfizer.com
> 
> Assuming that the next mod_jk2 release wants to go with the 
> present APR
> (0.94) or even the CVS (pre 1.0?) then we need to kludge 
> mod_jk on solaris 8 (at least) to not use APR for this bit.
> 

No it's gonna be 0.95 (the one distributed with httpd-2.0.48)

> I was going to add an && defined(foo) to the APR defined 
> lines, however I do not know the right foo to add __sun seems 
> too broad.  The next more complex fix is to alter the 
> Makefile with a -d.
> 
> What do people think?
> 

Look at my today post (JK2 shm).
It's going to use the shm.
If the platform is missing APR_HAS_SHARED_MEMORY the shm will be disabled.
Also you can alway set the shm to disabled if the APR platform MMAP is
buggy.

MT.



---------------------------------------------------------------------
To unsubscribe, e-mail: tomcat-dev-unsubscribe@jakarta.apache.org
For additional commands, e-mail: tomcat-dev-help@jakarta.apache.org
--- ./jk/native2/server/apache2/mod_jk2.c.orig  Thu Mar 04 18:24:50 2004
+++ ./jk/native2/server/apache2/mod_jk2.c       Mon Mar 08 04:08:44 2004
@@ -193,7 +193,7 @@
      * Here we must now 'fix' the content of the object passed in.
      * Apache doesn't care what we do here as it has the reference to the unique object that has been
      * created. What we need to do is ensure that the data given to mod_jk2 is correct. Hopefully in the long run
      * we can ignore some of the mod_jk details...
      */
 
     /* if applicable we will set the hostname etc variables. */
@@ -405,11 +405,11 @@
     if( s->is_virtual ) {
         /* Virtual host */
         ap_log_perror(APLOG_MARK, APLOG_DEBUG, 0, p,
-                      "mod_jk Create config for virtual host %s",
+                      "mod_jk2 Create config for virtual host %s",
                       s->server_hostname );
     } else {
         ap_log_perror(APLOG_MARK, APLOG_DEBUG, 0, p,
-                      "mod_jk Create config for default server %s",
+                      "mod_jk2 Create config for default server %s",
                       s->server_hostname );
     }
 
@@ -436,7 +436,7 @@
     jk_uriEnv_t *overrides = (jk_uriEnv_t *)overridesv;
     
     ap_log_perror(APLOG_MARK, APLOG_DEBUG, 0, p,
-                  "mod_jk Merging workerEnv");
+                  "mod_jk2 Merging workerEnv");
 
     
     /* The 'mountcopy' option should be implemented in common.
@@ -508,7 +508,7 @@
         *mainPool=gPool;
     
     /* We have a global pool ! */
-    apr_pool_userdata_get( &data, "mod_jk_init", gPool );
+    apr_pool_userdata_get( &data, "mod_jk2_init", gPool );
     if( data==NULL ) {
         return JK_OK;
     } else {
@@ -540,14 +540,14 @@
     if( rc == JK_OK && gPool != NULL ) {
         /* This is the first step */
         env->l->jkLog(env, env->l, JK_LOG_INFO,
-                      "mod_jk.post_config() first invocation\n");
+                      "mod_jk2.post_config() first invocation\n");
         
-        apr_pool_userdata_set( "INITOK", "mod_jk_init", NULL, gPool );
+        apr_pool_userdata_set( "INITOK", "mod_jk2_init", NULL, gPool );
         return OK;
     }
         
     env->l->jkLog(env, env->l, JK_LOG_INFO,
-                  "mod_jk.post_config() second invocation\n" ); 
+                  "mod_jk2.post_config() second invocation\n" ); 
     workerEnv->parentInit( env, workerEnv);
 
     return OK;
@@ -621,11 +621,11 @@
         jk2_init( env, pconf, workerEnv, s );
 
         if (workerEnv->childId <= 0) 
-            env->l->jkLog(env, env->l, JK_LOG_INFO, "mod_jk child %d initialized\n",
+            env->l->jkLog(env, env->l, JK_LOG_INFO, "mod_jk2 child %d initialized\n",
                           workerEnv->childId);
     }
     if (workerEnv->childGeneration)
-        env->l->jkLog(env, env->l, JK_LOG_ERROR, "mod_jk child workerEnv in error state %d\n",
+        env->l->jkLog(env, env->l, JK_LOG_ERROR, "mod_jk2 child workerEnv in error state %d\n",
                       workerEnv->childGeneration);
 
     /* Restore the process generation */
@@ -674,7 +674,7 @@
     /* Set up r->read_chunked flags for chunked encoding, if present */
     if(rc = ap_setup_client_block(r, REQUEST_CHUNKED_DECHUNK)) {
         env->l->jkLog(env, env->l, JK_LOG_INFO,
-                      "mod_jk.handler() Can't setup client block %d\n", rc);
+                      "mod_jk2.handler() Can't setup client block %d\n", rc);
         workerEnv->globalEnv->releaseEnv( workerEnv->globalEnv, env );
         return rc;
     }
@@ -684,21 +684,21 @@
     if( worker==NULL && uriEnv->workerName != NULL ) {
         worker=env->getByName( env, uriEnv->workerName);
         env->l->jkLog(env, env->l, JK_LOG_INFO, 
-                      "mod_jk.handler() finding worker for %#lx %#lx %s\n",
+                      "mod_jk2.handler() finding worker for %#lx %#lx %s\n",
                       worker, uriEnv, uriEnv->workerName);
         uriEnv->worker=worker;
     }
 
     if(worker==NULL || worker->mbean == NULL || worker->mbean->localName==NULL ) {
         env->l->jkLog(env, env->l, JK_LOG_ERROR, 
-                      "mod_jk.handle() No worker for %s\n", r->uri); 
+                      "mod_jk2.handle() No worker for %s\n", r->uri); 
         workerEnv->globalEnv->releaseEnv( workerEnv->globalEnv, env );
         return HTTP_INTERNAL_SERVER_ERROR;
     }
 
     if( uriEnv->mbean->debug > 0 )
         env->l->jkLog(env, env->l, JK_LOG_DEBUG, 
-                      "mod_jk.handler() serving %s with %#lx %#lx %s\n",
+                      "mod_jk2.handler() serving %s with %#lx %#lx %s\n",
                       uriEnv->mbean->localName, worker, worker->mbean, worker->mbean->localName );
 
     /* Get a pool for the request XXX move it in workerEnv to
@@ -708,7 +708,7 @@
         rPool=worker->mbean->pool->create( env, worker->mbean->pool, HUGE_POOL_SIZE );
         if( uriEnv->mbean->debug > 0 )
             env->l->jkLog(env, env->l, JK_LOG_DEBUG,
-                          "mod_jk.handler(): new rpool %#lx\n", rPool );
+                          "mod_jk2.handler(): new rpool %#lx\n", rPool );
     }
     
     s=(jk_ws_service_t *)rPool->calloc( env, rPool, sizeof( jk_ws_service_t ));
@@ -726,7 +726,7 @@
     s->uriEnv = uriEnv; 
 
     /* env->l->jkLog(env, env->l, JK_LOG_INFO,  */
-    /*              "mod_jk.handler() Calling %s\n", worker->mbean->name); */
+    /*              "mod_jk2.handler() Calling %s\n", worker->mbean->name); */
     
     rc = worker->service(env, worker, s);
     
@@ -748,7 +748,7 @@
     }
 
     env->l->jkLog(env, env->l, JK_LOG_ERROR,
-                  "mod_jk.handler() Error connecting to tomcat %d, status %d\n", rc, s->status);
+                  "mod_jk2.handler() Error connecting to tomcat %d, status %d\n", rc, s->status);
                   
     workerEnv->globalEnv->releaseEnv( workerEnv->globalEnv, env );
 
@@ -760,7 +760,7 @@
         return HTTP_INTERNAL_SERVER_ERROR;  
 }
 
 /** Use the internal mod_jk mappings to find if this is a request for
  *    tomcat and what worker to use. 
  */
 static int jk2_translate(request_rec *r)



Guenter.


---------------------------------------------------------------------
To unsubscribe, e-mail: tomcat-dev-unsubscribe@jakarta.apache.org
For additional commands, e-mail: tomcat-dev-help@jakarta.apache.org


Thanks to all commiters here

Posted by Guenter Knauf <ef...@gmx.net>.
Hi all,
I want to say a big THANKS to all commiters here for their fantastic work and co-work with the others here from the list -- that makes participating on an OpenSource project like the jt connectors much more fun.
Now we have not only made compiling for NetWare a lot easier, but also got mod_jk2 running on NetWare, and improved the mod_jk2 module for all platforms!
Also I want to give some more positive feedback I got from other users which where brave enough to test all the CVS builds I did in the past even already in production: they all said mod_jk2 is faster than mod_jk, and that on both NetWare and Win32 platforms! Now only a release can show up the remaining issues if there are any.

Again, thanks for all your help!

greets, Guenter.



---------------------------------------------------------------------
To unsubscribe, e-mail: tomcat-dev-unsubscribe@jakarta.apache.org
For additional commands, e-mail: tomcat-dev-help@jakarta.apache.org


Re: [PATCH] ./jk/native/isapi/isapi.dsp - remove notes.lib dependence

Posted by Henri Gomez <hg...@apache.org>.
Guenter Knauf wrote:

> Hi,
> this patch removes wrong dependence on notes.lib from isapi.dsp.
> 
> http://www.gknw.com/test/isapi.dsp.diff
> ========================================================================
> --- isapi.dsp.orig      Thu Feb 12 10:34:34 2004
> +++ isapi.dsp           Tue Mar 16 14:56:58 2004
> @@ -54,7 +54,7 @@
>  # ADD BSC32 /nologo
>  LINK32=link.exe
>  # ADD BASE LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib /nologo /dll /machine:I386
> -# ADD LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib wsock32.lib notes.lib /nologo /dll /machine:I386 /out:"Release/tomcat_redirector.dll" /libpath:"C:\notesapi\lib\mswin32"
> +# ADD LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib wsock32.lib /nologo /dll /machine:I386 /out:"Release/tomcat_redirector.dll"
>  
>  !ELSEIF  "$(CFG)" == "isapi - Win32 Debug"
>  
> @@ -81,7 +81,7 @@
>  # ADD BSC32 /nologo
>  LINK32=link.exe
>  # ADD BASE LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib /nologo /dll /debug /machine:I386 /pdbtype:sept
> -# ADD LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib wsock32.lib notes.lib /nologo /dll /debug /machine:I386 /out:"Debug/tomcat_redirector.dll" /pdbtype:sept /libpath:"C:\notesapi\lib\mswin32"
> +# ADD LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib wsock32.lib /nologo /dll /debug /machine:I386 /out:"Debug/tomcat_redirector.dll" /pdbtype:sept
>  
>  !ENDIF 

Commited.

PS: Guenter, take a look at the commit comment

---------------------------------------------------------------------
@@ -193,7 +193,7 @@
      * Apache doesn't care what we do here as it has the reference to the unique object that has been
      * created. What we need to do is ensure that the data given to mod_jk2 is correct. Hopefully in the long run
-     * we can ignore some of the mod_jk details...
+     * we can ignore some of the mod_jk2 details...
      */
 
@@ -760,7 +760,7 @@
 }
 
-/** Use the internal mod_jk mappings to find if this is a request for
+/** Use the internal mod_jk2 mappings to find if this is a request for
  *    tomcat and what worker to use. 
  */
To unsubscribe, e-mail: tomcat-dev-unsubscribe@jakarta.apache.org
For additional commands, e-mail: tomcat-dev-help@jakarta.apache.org


[PATCH] ./jk/native/isapi/isapi.dsp - remove notes.lib dependence

Posted by Guenter Knauf <ef...@gmx.net>.
Hi,
this patch removes wrong dependence on notes.lib from isapi.dsp.

http://www.gknw.com/test/isapi.dsp.diff
========================================================================